<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 01/21/2013 *
 * ===================                          Last change: 01/21/2013 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : ext-blacklist.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Blacklisting of email/URL addresses              *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  :                                                  *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Version number
setThisExtensionVersion('0.0.0');

// Version history array (add more with , '0.0.1' and so on)
setExtensionVersionHistory(array('0.0.0'));

// This extension is in development (non-productive)
enableExtensionProductive(FALSE);

switch (getExtensionMode()) {
	case 'setup': // Do stuff when installation is running
		// SQL commands to run
		addDropTableSql('blacklist');
		addCreateTableSql('blacklist', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`data` VARCHAR(255) NOT NULL DEFAULT '',
`pool_id` BIGINT(20) UNSIGNED NULL DEFAULT NULL,
`provider` VARCHAR(255) NOT NULL DEFAULT 'BLACKLIST',
`type` VARCHAR(20) NOT NULL DEFAULT 'INVALID',
`added` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
PRIMARY KEY (`id`),
INDEX (`provider`),
INDEX (`type`),
INDEX (`pool_id`)",
			'Generic blacklist');

		// Add admin menu
		addAdminMenuSql('setup', 'config_blacklist', 'Sperrlisten', 'Einstellungen zu den Sperrlisten.', 8);
		addAdminMenuSql('misc', 'list_blacklist', 'Sperrlisten...', 'Zeigt gesperrte Email-Adressen, IP-Adressen, URLs und vieles mehr an.', 3);

		// Add configuration
		addConfigAddSql('email_blacklist', "ENUM('Y','N') NOT NULL DEFAULT 'Y'");
		addConfigAddSql('ip_blacklist', "ENUM('Y','N') NOT NULL DEFAULT 'Y'");
		addConfigAddSql('url_blacklist', "ENUM('Y','N') NOT NULL DEFAULT 'Y'");

		// Register filters
		registerFilter(__FILE__, __LINE__, 'pre_user_registration' , 'CHECK_EMAIL_BLACKLISTED', FALSE, TRUE, isExtensionDryRun());
		registerFilter(__FILE__, __LINE__, 'pre_user_registration' , 'CHECK_IP_BLACKLISTED'   , FALSE, TRUE, isExtensionDryRun());
		registerFilter(__FILE__, __LINE__, 'pre_update_user_data'  , 'CHECK_EMAIL_BLACKLISTED', FALSE, TRUE, isExtensionDryRun());
		registerFilter(__FILE__, __LINE__, 'post_email_blacklisted', 'LOG_EMAIL_BLACKLISTED'  , FALSE, TRUE, isExtensionDryRun());
		registerFilter(__FILE__, __LINE__, 'post_ip_blacklisted'   , 'LOG_IP_BLACKLISTED'     , FALSE, TRUE, isExtensionDryRun());
		break;

	case 'remove': // Do stuff when removing extension
		// SQL commands to run
		addDropTableSql('blacklist');

		// Remove menu
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_admin_menu` WHERE `what` IN ('config_blacklist', 'list_blacklist')");

		// Unregister filters
		unregisterFilter(__FILE__, __LINE__, 'pre_user_registration' , 'CHECK_EMAIL_BLACKLISTED', TRUE, isExtensionDryRun());
		unregisterFilter(__FILE__, __LINE__, 'pre_user_registration' , 'CHECK_IP_BLACKLISTED'   , TRUE, isExtensionDryRun());
		unregisterFilter(__FILE__, __LINE__, 'pre_update_user_data'  , 'CHECK_EMAIL_BLACKLISTED', TRUE, isExtensionDryRun());
		unregisterFilter(__FILE__, __LINE__, 'post_email_blacklisted', 'LOG_EMAIL_BLACKLISTED'  , TRUE, isExtensionDryRun());
		unregisterFilter(__FILE__, __LINE__, 'post_ip_blacklisted'   , 'LOG_IP_BLACKLISTED'     , TRUE, isExtensionDryRun());
		break;

	case 'activate': // Do stuff when admin activates this extension
		// SQL commands to run
		break;

	case 'deactivate': // Do stuff when admin deactivates this extension
		// SQL commands to run
		break;

	case 'update': // Update an extension
		switch (getCurrentExtensionVersion()) {
			case '0.0.1': // SQL queries for v0.0.1
				addExtensionSql('');

				// Update notes (these will be set as task text!)
				setExtensionUpdateNotes('');
				break;
		} // END - switch
		break;

	case 'modify': // When the extension got modified
		break;

	case 'test': // For testing purposes
		break;

	case 'init': // Do stuff when extension is initialized
		break;

	default: // Unknown extension mode
		reportBug(__FILE__, __LINE__, sprintf("Unknown extension mode %s in extension %s detected.", getExtensionMode(), getCurrentExtensionName()));
		break;
} // END - switch

// [EOF]
?>
