<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 04/25/2005 *
 * ===================                          Last change: 05/19/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_sponsor.php                            *
 * -------------------------------------------------------------------- *
 * Short description : List all sponsors and their details              *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle Sponsoren und deren Details auflisten       *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

if (isGetRequestElementSet('id')) {
	// Show detailed informations to a sponsor
	$result = SQL_QUERY_ESC("SELECT
	`company`, `position`, `gender`, `surname`, `family`, `street_nr1`, `street_nr2`, `zip`, `city`, `country`,
	`phone`, `fax`, `cell`, `email`, `url`, `tax_ident`,
	`status`,
	UNIX_TIMESTAMP(`sponsor_created`) AS `sponsor_created`,
	UNIX_TIMESTAMP(`last_online`) AS `last_online`,
	UNIX_TIMESTAMP(`last_change`) AS `last_change`,
	`receive_warnings`,
	`points_amount`, `points_used`, `remote_addr`, `warning_interval`, `refid`, `ref_count`
FROM
	`{?_MYSQL_PREFIX?}_sponsor_data`
WHERE
	`id`=%s LIMIT 1",
	array(bigintval(getRequestElement('id'))), __FILE__, __LINE__);

	if (SQL_NUMROWS($result) == 1) {
		// Load sponsor details
		$content = SQL_FETCHARRAY($result);

		// Check if an entry is empty
		foreach ($content as $k => $v) {
			if ((empty($v)) && ($v != 0)) $content[$k] = '---';
		} // END - foreach

		// Prepare all data for the template
		//  Sponsor's id
		$content['id']              = getRequestElement('id');
		//  Contact data
		$content['email_link']      = generateEmailLink($content['email'], 'sponsor_data');
		//  Epoche times
		$content['sponsor_created'] = generateDateTime($content['sponsor_created'], 2);
		$content['last_online']     = generateDateTime($content['last_online'], 2);
		$content['last_change']     = generateDateTime($content['last_change'], 2);
		//  Orders total
		$content['orders']          = countSumTotalData(bigintval(getRequestElement('id')), 'sponsor_orders', 'id', 'sponsor_id', TRUE);

		// Load template
		loadTemplate('admin_list_sponsor_details', FALSE, $content);
	} else {
		// Sponsor not found
		displayMessage('{%message,ADMIN_SPONSOR_404=' . bigintval(getRequestElement('id')) . '%}');
	}

	// Free result
	SQL_FREERESULT($result);
} elseif (isGetRequestElementSet('refid')) {
	// Search for sponsor
	$result = SQL_QUERY_ESC("SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_data` WHERE `id`=%s LIMIT 1",
		array(bigintval(getRequestElement('refid'))), __FILE__, __LINE__);
	if (SQL_NUMROWS($result) == 1) {
		// Free memory
		SQL_FREERESULT($result);

		// Sponsor found so let's list all his referrals
		$result = SQL_QUERY_ESC("SELECT
	`id`,
	`gender`,
	`surname`,
	`family`,
	`email`,
	`status`,
	UNIX_TIMESTAMP(`sponsor_created`) AS `sponsor_created`,
	UNIX_TIMESTAMP(`last_online`) AS `last_online`,
	`points_amount`,
	`points_used`,
	`remote_addr`,
	`ref_count`
FROM
	`{?_MYSQL_PREFIX?}_sponsor_data`
WHERE
	`refid`='%s'
ORDER BY
	`id` ASC",
		array(bigintval(getRequestElement('refid'))), __FILE__, __LINE__);

		if (!SQL_HASZERONUMS($result)) {
			// List refs now
			// Free memory
			SQL_FREERESULT($result);
		} else {
			// No refs made so far
			displayMessage(getMaskedMessage('ADMIN_SPONSOR_REFS_404', '<a href="{%url=modules.php?module=admin&amp;what=list_sponsor&amp;id=' . bigintval(getRequestElement('refid')) . '%}">' . bigintval(getRequestElement('refid')) . '</a>'));
		}
	} else {
		// Sponsor not found
		displayMessage('{%message,ADMIN_SPONSOR_404=' . bigintval(getRequestElement('refid')) . '%}');
	}
} else {
	// List all sponsors
	$result_main = SQL_QUERY("SELECT
	`id`, `gender`, `surname`, `family`, `email`, `status`,
	UNIX_TIMESTAMP(`sponsor_created`) AS `sponsor_created`,
	UNIX_TIMESTAMP(`last_online`) AS `last_online`,
	`points_amount`, `points_used`,
	(`points_amount` + `points_used`) AS `points`,
	`remote_addr`
FROM
	`{?_MYSQL_PREFIX?}_sponsor_data`
ORDER BY
	`id` ASC", __FILE__, __LINE__);

	if (!SQL_HASZERONUMS($result_main)) {
		// At least one sponsor found
		$OUT = '';
		while ($content = SQL_FETCHARRAY($result_main)) {
			// Transfer data to array
			$content['email']           = generateEmailLink($content['email'], 'sponsor_data');
			$content['sponsor_created'] = generateDateTime($content['sponsor_created'], 2);
			$content['last_online']     = generateDateTime($content['last_online'], 2);

			// Load row template
			$OUT .= loadTemplate('admin_list_sponsor_row', TRUE, $content);
		} // END - while

		// Free memory
		SQL_FREERESULT($result_main);

		// Load final template
		loadTemplate('admin_list_sponsor', FALSE, $OUT);
	} else {
		// No sponsors registered so far
		displayMessage('{--ADMIN_SPONSOR_NONE_REGISTERED--}');
	}
}

// [EOF]
?>
